﻿-- Name:		moveAllImplements.lua
-- Description:	Implements the moveAllImplements specialization
-- Author:		Noobgetier (omgz@gmx.de)
-- Version:		1.0
-- Date:		2013-02-09
-- Change log:	1.0 - inital release


moveAllImplements = {};

function moveAllImplements.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function moveAllImplements:load(xmlFile)
	self.isSelectable = true;
	self.moveAllImplements = {};
	self.moveAllImplements.isEnabled = false;
	self.moveAllImplements.doLowering = false;
	self.moveAllImplements.attachedImplements = {};
end;

function moveAllImplements:readStream(streamId, connection)
end;

function moveAllImplements:writeStream(streamId, connection)
end;

function moveAllImplements:keyEvent(unicode, sym, modifier, isDown)
end;

function moveAllImplements:update(dt)
	if self:getIsActive() and self.isClient then
		if self:getIsActiveForInput() and self.moveAllImplements.isEnabled then
			if InputBinding.hasEvent(InputBinding.MOVE_IMPLEMENT_KEY) then
				for k, v in pairs(self.attachedImplements) do
					for i, v in pairs(self.moveAllImplements.attachedImplements) do
						if self.moveAllImplements.attachedImplements[i].implementIndex == k then
							self:setJointMoveDown(self.attachedImplements[k].jointDescIndex, self.moveAllImplements.doLowering);
							if self.moveAllImplements.attachedImplements[i].isFoldable then
								local direction = self.attachedImplements[k].object:getToggledFoldMiddleDirection();
								if self.attachedImplements[k].object:getIsFoldMiddleAllowed() then
									if self.moveAllImplements.doLowering and direction == -1 then
										self.attachedImplements[k].object:setFoldState(direction, true);
									end;
									if not self.moveAllImplements.doLowering and direction == 1 then
										self.attachedImplements[k].object:setFoldState(direction, true);
									end;
								end;
							end;
						end;
					end;
				end;
			end;
		end;
	end;
end;

function moveAllImplements:updateTick(dt)
	if self:getIsActiveForInput() and self.isClient then
		if self.attacherJoints ~= nil then
			local loopDone = false;
			self.moveAllImplements.attachedImplements = {};
			for j, v in pairs(self.attacherJoints) do					
				if self.attacherJoints[j].jointType == Vehicle.JOINTTYPE_IMPLEMENT and self.attacherJoints[j].allowsLowering then
					for i, v in pairs(self.attachedImplements) do
						if self.attachedImplements[i].jointDescIndex == j then
							local theImplement = {};
							theImplement.implementIndex = i;
							if SpecializationUtil.hasSpecialization(Foldable, self.attachedImplements[i].object.specializations) then
								theImplement.isFoldable = true;
							else
								theImplement.isFoldable = false;
							end;
							table.insert(self.moveAllImplements.attachedImplements, theImplement);
						end;
					end;
				end;
				if not loopDone then
					if self.attacherJoints[j].moveDown then
						self.moveAllImplements.doLowering = false;
						loopDone = true;
					else
						self.moveAllImplements.doLowering = true;
						loopDone = true;
					end;
				end;
			end;
		end;	
		if #self.moveAllImplements.attachedImplements > 1 then
			self.moveAllImplements.isEnabled = true;
		else
			self.moveAllImplements.isEnabled = false;
		end;
	end;
end;

function moveAllImplements:draw()
	if self.isClient and self:getIsActiveForInput() then
		if self.moveAllImplements.isEnabled then
			if self.moveAllImplements.doLowering then
				g_currentMission:addHelpButtonText(Steerable.LOWER_IMPLEMENT, InputBinding.MOVE_IMPLEMENT_KEY);
			else
				g_currentMission:addHelpButtonText(Steerable.LIFT_IMPLEMENT, InputBinding.MOVE_IMPLEMENT_KEY);
			end;
		end;
	end;
end;
	
function moveAllImplements:mouseEvent(posX, posY, isDown, isUp, button)
end;

function moveAllImplements:onDetach()
end;

function moveAllImplements:onAttach()
end;

function moveAllImplements:onEnter()
end;
	
function moveAllImplements:delete()
end;

function moveAllImplements:onLeave() 
end;
